dnl Autoconf macros for libpreludedb
dnl $id$

# Modified for LIBPRELUDEDB -- Thomas Andrejak
# Modified for LIBPRELUDEDB -- Yoann Vandoorselaere
# Modified for LIBGNUTLS -- nmav
# Configure paths for LIBGCRYPT
# Shamelessly stolen from the one of XDELTA by Owen Taylor
# Werner Koch   99-12-09

dnl AM_LIBPRELUDEDB([MINIMUM-VERSION, [ACTION-IF-FOUND [, ACTION-IF-NOT-FOUND ]]], THREAD_SUPPORT)
dnl Test for libpreludedb, and define LIBPRELUDEDB_CFLAGS, LIBPRELUDEDB_LDFLAGS, and LIBPRELUDEDB_LIBS
dnl
AC_DEFUN([AM_LIBPRELUDEDB],
[dnl
dnl Get the cflags and libraries from the libpreludedb pkg-config file
dnl
AC_ARG_ENABLE(libpreludedb, AC_HELP_STRING(--enable-libpreludedb, Define whether LibPreludeDB is required), libpreludedb_required="yes", enable_libpreludedb="yes")
if test x$enable_libpreludedb = xyes; then
  no_libpreludedb=""
  min_libpreludedb_version=ifelse([$1], ,0.1.0,$1)
  PKG_CHECK_MODULES([LIBPRELUDEDB], [libpreludedb >= $min_libpreludedb_version],
     [AC_CHECK_HEADER(libpreludedb/preludedb.h, enable_libpreludedb=yes, enable_libpreludedb=no)],
     [enable_libpreludedb=no])
  if test "x$enable_libpreludedb" = xno ; then
    no_libpreludedb="no"
    ifelse([$3], , :, [$3])
  else
    AC_MSG_CHECKING(libpreludedb $min_libpreludedb_version usability)

    libpreludedb_config_version=`$PKG_CONFIG libpreludedb --modversion`

    ac_save_CFLAGS="$CFLAGS"
    ac_save_LDFLAGS="$LDFLAGS"
    ac_save_LIBS="$LIBS"
    CFLAGS="$CFLAGS $LIBPRELUDEDB_CFLAGS"
    LDFLAGS="$LDFLAGS $LIBPRELUDEDB_LDFLAGS"
    LIBS="$LIBS $LIBPRELUDEDB_LIBS"

dnl
dnl Now check if the installed libpreludedb is sufficiently new. Also sanity
dnl checks the results of libpreludedb-config to some extent
dnl
    rm -f conf.libpreludedbtest
    AC_TRY_RUN([
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <libpreludedb/preludedb-version.h>

int
main ()
{
    system ("touch conf.libpreludedbtest");

    if( strcmp( preludedb_check_version(NULL), "$libpreludedb_config_version" ) )
    {
      printf("\n*** 'pkg-config libpreludedb --modversion' returned %s, but LIBPRELUDEDB (%s)\n",
             "$libpreludedb_config_version", preludedb_check_version(NULL) );
      printf("*** was found! If pkg-config was correct, then it is best\n");
      printf("*** to remove the old version of LIBPRELUDEDB.\n");
    }
    else if ( strcmp(preludedb_check_version(NULL), LIBPRELUDEDB_VERSION ) )
    {
      printf("\n*** LIBPRELUDEDB header file (version %s) does not match\n", LIBPRELUDEDB_VERSION);
      printf("*** library (version %s)\n", preludedb_check_version(NULL) );
    }
    else
    {
      if ( preludedb_check_version( "$min_libpreludedb_version" ) )
      {
        return 0;
      }
     else
      {
        printf("no\n*** An old version of LIBPRELUDEDB (%s) was found.\n",
                preludedb_check_version(NULL) );
        printf("*** You need a version of LIBPRELUDEDB newer than %s. The latest version of\n",
               "$min_libpreludedb_version" );
        printf("*** LIBPRELUDEDB is always available from https://www.prelude-siem.org/project/prelude/files\n");
        printf("*** \n");
        printf("*** If you have already installed a sufficiently new version, this error\n");
        printf("*** probably means that the wrong copy of the libpreludedb pkg-config file is\n");
        printf("*** being found.\n");
      }
    }
  return 1;
}
],, no_libpreludedb=yes,[echo $ac_n "cross compiling; assumed OK... $ac_c"])
    CFLAGS="$ac_save_CFLAGS"
    LIBS="$ac_save_LIBS"
    LDFLAGS="$ac_save_LDFLAGS"

    if test "x$no_libpreludedb" = x ; then
      AC_MSG_RESULT(yes)
      ifelse([$2], , :, [$2])
    else
      if test -f conf.libpreludedbtest ; then
        :
      else
        AC_MSG_RESULT(no)
        echo "*** Could not run libpreludedb test program, checking why..."
        CFLAGS="$CFLAGS $LIBPRELUDEDB_CFLAGS"
        LDFLAGS="$LDFLAGS $LIBPRELUDEDB_LDFLAGS"
        LIBS="$LIBS $LIBPRELUDEDB_LIBS"
        AC_TRY_LINK([
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <libpreludedb/preludedb-version.h>
],      [ return !!preludedb_check_version(NULL); ],
        [ echo "*** The test program compiled, but did not run. This usually means"
          echo "*** that the run-time linker is not finding LIBPRELUDEDB or finding the wrong"
          echo "*** version of LIBPRELUDEDB. If it is not finding LIBPRELUDEDB, you'll need to set your"
          echo "*** LD_LIBRARY_PATH environment variable, or edit /etc/ld.so.conf to point"
          echo "*** to the installed location  Also, make sure you have run ldconfig if that"
          echo "*** is required on your system"
          echo "***"
          echo "*** If you have an old version installed, it is best to remove it, although"
          echo "*** you may also be able to get things to work by modifying LD_LIBRARY_PATH"
          echo "***" ],
        [ echo "*** The test program failed to compile or link. See the file config.log for the"
          echo "*** exact error that occured. This usually means LIBPRELUDEDB was incorrectly installed"
          echo "*** or that you have moved LIBPRELUDEDB since it was installed. In the latter case, you"
          echo "*** may want to edit the libpreludedb pkg-config file" ])
        CFLAGS="$ac_save_CFLAGS"
        LDFLAGS="$ac_save_LDFLAGS"
        LIBS="$ac_save_LIBS"
      fi
      LIBPRELUDEDB_CFLAGS=""
      LIBPRELUDEDB_LDFLAGS=""
      LIBPRELUDEDB_LIBS=""
      ifelse([$3], , :, [$3])
    fi
    rm -f conf.libpreludedbtest
    AC_SUBST(LIBPRELUDEDB_CFLAGS)
    AC_SUBST(LIBPRELUDEDB_LDFLAGS)
    AC_SUBST(LIBPRELUDEDB_LIBS)
  fi
  if test x$enable_libpreludedb = xno && test x$libpreludedb_required = xyes; then
    AC_MSG_ERROR([Could not find libpreludedb library])
  fi
fi
])

dnl *-*wedit:notab*-*  Please keep this as the last line.
